Algebras
========

.. toctree::
   :maxdepth: 1

   sage/algebras/catalog

   quantum_groups

Free associative algebras and quotients
---------------------------------------

.. toctree::
   :maxdepth: 1

   sage/algebras/free_algebra
   sage/algebras/free_algebra_element

   sage/algebras/letterplace/free_algebra_letterplace
   sage/algebras/letterplace/free_algebra_element_letterplace
   sage/algebras/letterplace/letterplace_ideal

   sage/algebras/free_algebra_quotient
   sage/algebras/free_algebra_quotient_element
   sage/algebras/tensor_algebra

Finite dimensional algebras
---------------------------

.. toctree::
   :maxdepth: 1

   sage/algebras/finite_dimensional_algebras/finite_dimensional_algebra
   sage/algebras/finite_dimensional_algebras/finite_dimensional_algebra_element
   sage/algebras/finite_dimensional_algebras/finite_dimensional_algebra_ideal
   sage/algebras/finite_dimensional_algebras/finite_dimensional_algebra_morphism

Named associative algebras
--------------------------

.. toctree::
   :maxdepth: 1

   sage/algebras/affine_nil_temperley_lieb
   sage/algebras/askey_wilson
   sage/combinat/diagram_algebras
   sage/algebras/clifford_algebra
   sage/algebras/clifford_algebra_element
   sage/algebras/cluster_algebra
   sage/combinat/descent_algebra
   sage/algebras/down_up_algebra
   sage/algebras/exterior_algebra_groebner
   fusion_rings
   sage/algebras/hall_algebra
   sage/combinat/posets/incidence_algebras
   sage/algebras/group_algebra
   sage/combinat/grossman_larson_algebras
   sage/combinat/posets/moebius_algebra
   sage/algebras/orlik_terao
   sage/algebras/orlik_solomon
   sage/combinat/partition_algebra
   sage/algebras/quantum_clifford
   sage/algebras/quantum_groups/quantum_group_gap
   sage/algebras/quantum_matrix_coordinate_algebra
   sage/algebras/quantum_oscillator
   sage/algebras/quatalg/quaternion_algebra
   sage/algebras/rational_cherednik_algebra
   sage/algebras/schur_algebra
   sage/algebras/steenrod/steenrod_algebra
   sage/algebras/steenrod/steenrod_algebra_bases
   sage/algebras/steenrod/steenrod_algebra_misc
   sage/algebras/steenrod/steenrod_algebra_mult
   sage/algebras/weyl_algebra
   sage/algebras/yangian

Hecke algebras
--------------

.. toctree::
   :maxdepth: 1

   sage/algebras/hecke_algebras/ariki_koike_algebra
   sage/algebras/hecke_algebras/ariki_koike_specht_modules
   sage/algebras/iwahori_hecke_algebra
   sage/algebras/nil_coxeter_algebra
   sage/algebras/yokonuma_hecke_algebra
   cubic_hecke_algebra

Graded algebras
---------------

.. toctree::
   :maxdepth: 1

   sage/algebras/finite_gca
   sage/algebras/commutative_dga

Various associative algebras
----------------------------

.. toctree::
   :maxdepth: 1

   sage/algebras/associated_graded
   sage/algebras/cellular_basis
   sage/algebras/q_system
   sage/algebras/q_commuting_polynomials
   sage/algebras/splitting_algebra

Non-associative algebras
------------------------

.. toctree::
   :maxdepth: 1

   sage/algebras/octonion_algebra
   lie_algebras
   lie_conformal_algebras
   sage/algebras/jordan_algebra
   sage/combinat/free_dendriform_algebra
   sage/combinat/free_prelie_algebra
   sage/algebras/shuffle_algebra
   sage/algebras/free_zinbiel_algebra

.. include:: ../footer.txt

